==> haskell-rsa-2.3.0-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.0
id: RSA-2.3.0-A8bIidiWRZk9MJvdt2KMZJ
key: RSA-2.3.0-A8bIidiWRZk9MJvdt2KMZJ
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: dedbd38afa1ac1e523f00dddc61a3321
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/RSA-2.3.0
hs-libraries: HSRSA-2.3.0-A8bIidiWRZk9MJvdt2KMZJ
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
    crypto-pubkey-types-0.4.3-5rpJH9jHiAO1lLDqa5lm4l
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=04b47272348e9aa5648e546d18028ecd
             crypto-pubkey-types-0.4.3-5rpJH9jHiAO1lLDqa5lm4l=4d4a44aa14cd68a6cfe2c95bd20a8985
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.3.0-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.0
id: RSA-2.3.0-opumyRl4U8BxtutCBx8tu
key: RSA-2.3.0-opumyRl4U8BxtutCBx8tu
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: 3e78068f28dddb7170444f7ae755f3e8
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/RSA-2.3.0
hs-libraries: HSRSA-2.3.0-opumyRl4U8BxtutCBx8tu
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
    crypto-pubkey-types-0.4.3-5rpJH9jHiAO1lLDqa5lm4l
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=b38ee8fa4c1e132a024035423192fcff
             crypto-pubkey-types-0.4.3-5rpJH9jHiAO1lLDqa5lm4l=4d4a44aa14cd68a6cfe2c95bd20a8985
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=7fdfeaf1e3416ffd434c90cf824fb303
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
